@@ -1,13 +1,13 @@
 package CGI::Session::Serialize::storable;
 
-# $Id: storable.pm 420 2008-07-08 01:23:06Z markstos $
+# $Id: storable.pm 447 2008-11-01 03:46:08Z markstos $
 
 use strict;
 use Storable;
 require CGI::Session::ErrorHandler;
 
-$CGI::Session::Serialize::storable::VERSION = '4.33';
-@CGI::Session::Serialize::ISA               = ( "CGI::Session::ErrorHandler" );
+$CGI::Session::Serialize::storable::VERSION = '4.38';
+@CGI::Session::Serialize::storable::ISA               = ( "CGI::Session::ErrorHandler" );
 
 =pod
 
